; In Dragon Warrior's main script, text is printed to the main dialogue window with neither sound effects nor automatic line indenting until the first byte
; $50 (opening single quote) or $57 (one of the various space tiles) is encountered, upon which both the text printing sound effect and the automatic
; indenting are enabled for the remainder of the current string with no way to revert to silent, non-indented text.
;
; This patch modifies Dragon Warrior's text engine to make it recognize the $EE byte as a control code that disables the text printing sound effect and
; automatic indenting. Subsequent uses of the $50 or $57 byte will re-enable these effects. Since the unmodified game does not make use of the $EE byte
; in its main script, this patch will be of limited interest to non-hackers.
;
; This patch is compatible with both the PRG0 and PRG1 versions of Dragon Warrior.


norom

; Overwrite 4 bytes of existing code to hook into our new code.
org $7695
base $B685

	jmp update_sound_flag
	nop
rest_of_code:



; New code in space not used by an unmodified ROM.
; If you want to relocate this code, you'll need to put it somewhere with 24 ($18) bytes of free space.
org $7EAF
base $BE9F

update_sound_flag:
	cmp #$EE
	beq sound_off
	cmp #$EF
	beq ef_handler_jmp
	bne sound_same
sound_off:
	ldx #$00
	stx $650A	; $650A's value is what determines whether the text printing sound effect and automatic indenting will be applied
	jmp $B679
sound_same:
	jmp rest_of_code

ef_handler_jmp:
	jmp $B6FE